/*
    S60Bible A Bible Reader for SymbianOS
    Copyright (C) 2004 Yohanes Nugroho

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Yohanes Nugroho (yohanes@opensource.or.id)
    Kp Areman RT 09/08 No 71 Desa Tugu Cimanggis Depok 16951 Indonesia
*/

/*
Note: This is not very efficient, I should have used streams
*/

#include "CStringList.h"
#include "log.h"
#include <eikenv.h>
#include <e32base.h>

CStringList::CStringList(RFs &aFs)
{
	iFs = aFs;
}

CStringList* CStringList::NewL(RFs &aFs)
{
	CStringList* self = CStringList::NewLC(aFs);
	CleanupStack::Pop(self);
	return self;
}

CStringList* CStringList::NewLC(RFs &aFs)
{
	CStringList* self = new (ELeave) CStringList(aFs);
	CleanupStack::PushL(self);
	self->ConstructL();
	return self;
}


void CStringList::Copy(CStringList *strlist)
{
	for(int i=0; i<strlist->Content()->Count(); i++) {
		AddStringL((*(strlist->Content()))[i]);
	}
}

CStringList::~CStringList()
{
	Clear();
	delete iStrings;
}

CDesCArrayFlat * CStringList::Content()
{
	return iStrings;
}


void CStringList::ConstructL()
{
	iStrings = new CDesCArrayFlat(2);
}

void CStringList::Clear()
{
	iStrings->Reset();
}

void CStringList::LoadFromFileL(TDesC &name)
{
	RFile rf;
	error = rf.Open(iFs, name, EFileRead);
	if (error!=KErrNone) return;
	TFileText ftext;
	ftext.Set(rf);
	TBuf<256> line;
	TInt rs;
	Clear();
	do {
		rs = ftext.Read(line);
		if (rs==KErrNone) AddStringL(line);
	} while (rs==KErrNone);
	rf.Close();
}

void CStringList::SaveToFileL(TDesC &name)
{
/*
  RFile rf;
  rf.Replace(iFs, name, EFileWrite);
  TFileText ftext;
  ftext.Set(rf);
  TInt rs;

  for(int i=0; i<iStrings->Count(); i++) {
          rs = ftext.Write((*iStrings)[i]);
          if (rs!=KErrNone) break;
  }
  rf.Close();
*/
  int len=0;

        int i;
	for(i=0; i<iStrings->Count(); i++) {
               len += ((*iStrings)[i]).Length();
               len +=2;
	}
	iFs.MkDirAll(name);	
        RFile rf;
        if (rf.Replace(iFs, name, EFileWrite)!=KErrNone) {
        		Log(_L("Failed creating file"));
        		Log(name);
        		return;
        }
        TFileText ftext;
        ftext.Set(rf);
	if (len != 0) {
        HBufC *hb = HBufC::NewLC(len);
        _LIT(CR, "\n");
        for(i=0; i<iStrings->Count(); i++) {
               (hb->Des()).Append(((*iStrings)[i]));
               if (i!=iStrings->Count()-1) (hb->Des()).Append(CR);
        }
        TInt rs;
        //rs = ftext.Write((*iStrings)[i]);
        rs = ftext.Write(*hb);
		CleanupStack::PopAndDestroy(hb);
	}
    //if (rs!=KErrNone) break;
    rf.Close();
}

void CStringList::AddStringL(const TDesC &aValue)
{
	iStrings->AppendL(aValue);
}

void CStringList::AddNumberL(const int aValue)
{
	TBuf<20> num;
	num.SetLength(0);
	num.AppendNum(aValue);
	iStrings->AppendL(num);
}

TInt CStringList::GetNumberAt(const int aIndex)
{
	if (aIndex>=iStrings->Count()) return -1;
	TPtrC str = ((*iStrings)[aIndex]);
	int num = 0;
        TLex t(str);
        t.Val(num);
        return num;
}


void CStringList::PrependL(const TDesC &value)
{
	iStrings->InsertL(0, value);
}

void CStringList::Delete(int pos)
{
	iStrings->Delete(pos);
}

int CStringList::Count()
{
	return iStrings->Count();
}

