/*
    S60Bible A Bible Reader for SymbianOS
    Copyright (C) 2004 Yohanes Nugroho

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Yohanes Nugroho (yohanes@opensource.or.id)
    Kp Areman RT 09/08 No 71 Desa Tugu Cimanggis Depok 16951 Indonesia
*/


#include <coecobs.h>
#include <eikenv.h>
#include <eikspane.h>
#include <aknviewappui.h>

#include "BookmarkContainer.h"
#include "S60BibleDocument.h"
#include <S60Bible.rsg>


CBookmarkContainer* CBookmarkContainer::NewL(CAknView *aView, CS60BibleDocument* aDocument)
{
	CBookmarkContainer* self = CBookmarkContainer::NewLC(aView, aDocument);
	CleanupStack::Pop(self);
	return self;
}

CBookmarkContainer* CBookmarkContainer::NewLC(CAknView *aView, CS60BibleDocument* aDocument)
{
	CBookmarkContainer* self = new (ELeave) CBookmarkContainer;
	CleanupStack::PushL(self);
	self->ConstructL(aView, aDocument);
	return self;
}


void CBookmarkContainer::ConstructL(CAknView *aView, CS60BibleDocument* aDocument)
{
	iDocument = aDocument;
	CreateWindowL();
	SetMopParent(aView);
	iListBox = new( ELeave ) CAknDoubleStyleListBox();
	iTextArray = aDocument->Model()->GetBookmark();
	iListBox->ConstructL( this, 0 );
	iListBox->CreateScrollBarFrameL(ETrue); 
	iListBox->ScrollBarFrame()->SetScrollBarVisibilityL(
		CEikScrollBarFrame::EOn, 
		CEikScrollBarFrame::EAuto );

	iListBox->Model()->SetItemTextArray( iTextArray );
	//owned by Viewer (model)
	iListBox->Model()->SetOwnershipType( ELbmDoesNotOwnItemArray );
	
	TInt currentItem = iListBox->CurrentItemIndex();
        if ( iListBox->ScrollBarFrame() )
        {
                iListBox->ScrollBarFrame()->MoveVertThumbTo( currentItem );
        }
	
	iView = aView;
	
	SizeChanged();
	
	SetRect(aView->ClientRect());
	ActivateL();
}

void CBookmarkContainer::SizeChanged()
{
	if (iListBox) {
		iListBox->SetRect( Rect() );
	}
}

CBookmarkContainer::~CBookmarkContainer()
{
    	delete iListBox;
}

TInt CBookmarkContainer::CountComponentControls() const
{
	return 1; // return nbr of controls inside this container
}

CCoeControl* CBookmarkContainer::ComponentControl(TInt aIndex) const
{
	switch ( aIndex ){
		case 0:
			return iListBox;
		default:
			return NULL;
	}
}

void CBookmarkContainer::Draw(const TRect& aRect) const
{
	CWindowGc& gc = SystemGc();
	gc.SetPenStyle(CGraphicsContext::ENullPen);
	gc.SetBrushColor(KRgbWhite);
	gc.SetBrushStyle(CGraphicsContext::ESolidBrush);
	gc.DrawRect(aRect);
}

void CBookmarkContainer::HandleControlEventL(
    CCoeControl* /*aControl*/,
    TCoeEvent /*aEventType*/)
{
    // TODO: Add your control event handler code here
}

void CBookmarkContainer::GotoBookmark()
{
	int idx = iListBox->CurrentItemIndex();
	if (idx==-1) return;
	
	TBuf<100> verse;
	verse = (*iTextArray)[idx];
	char buff[100];
	Mem::Fill(buff, sizeof buff, 0);
	for(int i=1; i<verse.Length(); i++){
		if (((char)verse[i])=='\t') break;
		buff[i-1] = (char)verse[i];
	}
	if (iDocument->Model()->SeekVerseAsString(1, buff)) {
		iDocument->Model()->ClearVerse();
		iDocument->Model()->FillVerse();
		iView->HandleCommandL(EAknSoftkeyBack);
	} else {
		CAknNoteDialog* dlg = new CAknNoteDialog();
		dlg->ExecuteLD(R_VERSENOTFOUND);
	}
}

#ifdef __SERIES60_30__
void CBookmarkContainer::HandleResourceChange(TInt aType)
{
	CCoeControl::HandleResourceChange(aType);
    if  ( aType == KEikDynamicLayoutVariantSwitch ) {
    	TRect rect;
    	AknLayoutUtils::LayoutMetricsRect(AknLayoutUtils::EMainPane, rect);    	
		SetRect(rect);
		
    }
	iListBox->DrawNow();
}
#endif

void CBookmarkContainer::DelBookmark()
{
	if (iListBox->CurrentItemIndex()<0) return;
	iDocument->Model()->DelBookmark(iListBox->CurrentItemIndex());
	iDocument->Model()->SaveBookmarkL();
	iListBox->SetCurrentItemIndex(0);
	iListBox->HandleItemRemovalL();
	iListBox->SetCurrentItemIndexAndDraw(0);
}

void CBookmarkContainer::DelAll()
{
	if (iListBox->CurrentItemIndex()<0) return;
	iDocument->Model()->DelAllBookmark();
	iDocument->Model()->SaveBookmarkL();
	iListBox->SetCurrentItemIndexAndDraw(0);
	iListBox->HandleItemRemovalL();
	iListBox->SetCurrentItemIndexAndDraw(0);
}


TKeyResponse CBookmarkContainer::OfferKeyEventL(
    const TKeyEvent& aKeyEvent,
    TEventCode aType )
{
	if ( aType != EEventKey ) {
        	return EKeyWasNotConsumed;
        }
        
	if (aKeyEvent.iScanCode == EStdKeyUpArrow) {
        	if (iListBox->CurrentItemIndex()==0) {
        		iListBox->SetCurrentItemIndexAndDraw(iTextArray->Count()-1);
        		return EKeyWasConsumed;
        	}
        }
	if (aKeyEvent.iScanCode == EStdKeyDownArrow) {
        	if (iListBox->CurrentItemIndex()==iTextArray->Count()-1) {
        		iListBox->SetCurrentItemIndexAndDraw(0);
        		return EKeyWasConsumed;
        	}
        }
        
	if (aKeyEvent.iScanCode == EStdKeyDevice3) {
        	GotoBookmark();
        	return EKeyWasConsumed;
	}
        if (iListBox) {
        	return iListBox->OfferKeyEventL( aKeyEvent, aType );
        }
        return EKeyWasNotConsumed;
}

void CBookmarkContainer::HandleListBoxEventL(
    CEikListBox* /*aListBox*/,
    TListBoxEvent aEventType )
{
    if ( ( aEventType == MEikListBoxObserver::EEventEnterKeyPressed ) ||
         ( aEventType == MEikListBoxObserver::EEventItemClicked ) || 
         ( aEventType == MEikListBoxObserver::EEventItemDoubleClicked )
         ) {
        	GotoBookmark();
	}
}

