/*
    S60Bible A Bible Reader for SymbianOS
    Copyright (C) 2004 Yohanes Nugroho

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Yohanes Nugroho (yohanes@opensource.or.id)
    Kp Areman RT 09/08 No 71 Desa Tugu Cimanggis Depok 16951 Indonesia
*/

#include <barsread.h>
#include <S60Bible.rsg>
#include "S60Bible.hrh"
#include "KeyBindingList.h"
#include "Viewer.h"
#include "S60BibleDocument.h"

CKeyBindingList *CKeyBindingList::NewL(CAknView *aView,  CS60BibleDocument* aDocument)
{
	CKeyBindingList* self = CKeyBindingList::NewLC(aView, aDocument);
	CleanupStack::Pop(self);
	return self;
}

CKeyBindingList *CKeyBindingList::NewLC(CAknView *aView,  CS60BibleDocument* aDocument)
{
	CKeyBindingList* self = new (ELeave) CKeyBindingList(aView, aDocument);
	CleanupStack::PushL(self);
	return self;
}

CKeyBindingList::CKeyBindingList(CAknView *aView,  CS60BibleDocument* aDocument) : 
	CAknSettingItemList(), iView(aView), iDocument(aDocument)
{
	SetRect(Rect());
	SizeChanged();
}

CKeyBindingList::~CKeyBindingList()
{
	// no specific destruction code required - no owned data
}


void CKeyBindingList::SizeChanged()
{
	// if size changes, make sure component takes whole available space
	
	CEikFormattedCellListBox *listbox = ListBox();
	
	if (listbox) {
		listbox->SetRect(Rect());
	}
}

void CKeyBindingList::EditCurrentItemL()
{
	// invoke EditItemL on the current item
	EditItemL(ListBox()->CurrentItemIndex(),  ETrue);		
}


void CKeyBindingList::Draw(const TRect& /*aRect*/) const
{
}


CAknSettingItem * CKeyBindingList::CreateSettingItemL (TInt aIdentifier) 
{
	CAknSettingItem* settingItem = NULL;
	if (aIdentifier>=400 && aIdentifier<=415) {
		settingItem = new (ELeave) CAknEnumeratedTextPopupSettingItem (
			aIdentifier, iDocument->Model()->GetBinding(aIdentifier-400));

	}
    	return settingItem;
}

